==> deailab-0.1.1.tar.gz: deailab-0.1.1/src/document/plugins.ts <==
import {
  JupyterFrontEnd,
  JupyterFrontEndPlugin
} from '@jupyterlab/application';
import { IThemeManager, WidgetTracker } from '@jupyterlab/apputils';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';

import { IBhlViewerTracker } from '../token';
import { bhlIcon } from '../utils';
import { BhlDocWidget } from './bhlDocWidget';
import { BhlDocWidgetFactory } from './widgetFactory';

export const bhlPlugin: JupyterFrontEndPlugin<IBhlViewerTracker> = {
  id: 'bhl-lab:document-plugin',
  autoStart: true,
  provides: IBhlViewerTracker,
  requires: [IRenderMimeRegistry],
  optional: [IThemeManager],
  activate: (
    app: JupyterFrontEnd,
    rendermime: IRenderMimeRegistry,
    themeManager: IThemeManager
  ) => {
    const tracker = new WidgetTracker<BhlDocWidget>({
      namespace: 'bhl-lab:widgets'
    });
    const widgetFactory = new BhlDocWidgetFactory({
      name: 'DeAI',
      fileTypes: ['deai'],
      defaultFor: ['deai'],
      rendermime,
      commands: app.commands,
      themeManager,
      serviceManager: app.serviceManager
    });
    widgetFactory.widgetCreated.connect((_, widget) => {
      widget.context.pathChanged.connect(() => {
        tracker.save(widget);
      });
      tracker.add(widget);
    });
    app.docRegistry.addWidgetFactory(widgetFactory);
    // register the filetype
    app.docRegistry.addFileType({
      name: 'deai',
      icon: bhlIcon,
      displayName: 'DEAI',
      mimeTypes: ['text/json'],
      extensions: ['.deai', '.DEAI'],
      fileFormat: 'json',
      contentType: 'file'
    });
    return tracker;
  }
};

==> deailab-0.1.11.tar.gz: deailab-0.1.11/src/document/plugins.ts <==
import {
  JupyterFrontEnd,
  JupyterFrontEndPlugin
} from '@jupyterlab/application';
import { IThemeManager, WidgetTracker } from '@jupyterlab/apputils';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';

import { IBhlViewerTracker } from '../token';
import { bhlIcon } from '../utils';
import { BhlDocWidget } from './bhlDocWidget';
import { BhlDocWidgetFactory } from './widgetFactory';

export const bhlPlugin: JupyterFrontEndPlugin<IBhlViewerTracker> = {
  id: 'bhl-lab:document-plugin',
  autoStart: true,
  provides: IBhlViewerTracker,
  requires: [IRenderMimeRegistry, IDocumentManager],
  optional: [IThemeManager],
  activate: (
    app: JupyterFrontEnd,
    rendermime: IRenderMimeRegistry,
    docManager: IDocumentManager,
    themeManager: IThemeManager
  ) => {
    const tracker = new WidgetTracker<BhlDocWidget>({
      namespace: 'bhl-lab:widgets'
    });
    const widgetFactory = new BhlDocWidgetFactory({
      name: 'DeAI',
      fileTypes: ['deai'],
      defaultFor: ['deai'],
      rendermime,
      commands: app.commands,
      themeManager,
      serviceManager: app.serviceManager,
      docManager
    });
    widgetFactory.widgetCreated.connect((_, widget) => {
      widget.context.pathChanged.connect(() => {
        tracker.save(widget);
      });
      tracker.add(widget);
    });
    app.docRegistry.addWidgetFactory(widgetFactory);
    // register the filetype
    app.docRegistry.addFileType({
      name: 'deai',
      icon: bhlIcon,
      displayName: 'DEAI',
      mimeTypes: ['text/json'],
      extensions: ['.deai', '.DEAI'],
      fileFormat: 'json',
      contentType: 'file'
    });
    return tracker;
  }
};
